package rest.controller

import groovy.json.JsonBuilder
import org.bonitasoft.web.extension.rest.RestAPIContext
import org.bonitasoft.web.extension.rest.RestApiController
import org.bonitasoft.web.extension.rest.RestApiResponse
import org.bonitasoft.web.extension.rest.RestApiResponseBuilder

import javax.servlet.http.HttpServletRequest

class GetOrders implements RestApiController {

  private final static String PAGE_PARAM_NAME = "p"
  private final static String COUNT_PARAM_NAME = "c"

  @Override
  RestApiResponse doHandle(HttpServletRequest request, RestApiResponseBuilder responseBuilder, RestAPIContext context) {
    SearchOptions options = buildSearchParameters(request)
    def orders = options.startIndex()..options.endIndex()
    return responseBuilder.withResponse(new JsonBuilder(orders).toString()).withResponseStatus(200).build()
  }

  private SearchOptions buildSearchParameters(HttpServletRequest request) {
    SearchOptions options = new SearchOptions()
    options.page = request.getParameter(PAGE_PARAM_NAME)?.toInteger() ?: 0
    options.count = request.getParameter(COUNT_PARAM_NAME)?.toInteger() ?: Integer.MAX_VALUE
    return options
  }

  private class SearchOptions {
    Integer page
    Integer count

    int startIndex() {
      page * count
    }

    int endIndex() {
      startIndex() + count - 1
    }
  }

}


